Extra widgets for the Iced GUI library.
Re-exports
pub use expander::Expander;expanderpub use ribbon::Ribbon;ribbonpub use selector_bar::SelectorBar;selector_bar
Modules
- expander
expander - A flexible container widget that can open or close in any direction to reveal or conceal its contents.
- ribbon
ribbon - A horizontal set of Groups that adapt their appearance and arrangement when the Ribbon is resized.
- selector_
bar selector_bar - A
SelectorBarprovides single selection from a collection ofItems highlighted by an indicator.
Functions
- expander
expander - Creates a new
Expanderfrom the provided header and content. - ribbon
ribbon - Creates a new
Ribbonwhich the providedGroups. - selector_
bar selector_bar - Creates a new
SelectorBarwhich the providedItems.