Module expander

Module expander 

Available on crate feature expander only.
A flexible container widget that can open or close in any direction to reveal or conceal its contents.

Example

enum Message {
    ExpanderPressed,
}

let mut expander = expander(
    button("Header").on_press(Message::ExpanderPressed),
    column!["Item 1", "Item 2", "Item 3"],
);

if self.is_expanded {
    expander = expander.expand();
}

Structs

Expander
A collapsible container widget that can expand or collapse in any direction to show or hide its content.
Id
Identifies an Expander, primarily to indicate when animation state should be reset.

Enums

Direction