Group

Struct Group 

pub struct Group<'a, Id, Message, Theme = Theme, Renderer = Renderer>
where Id: Clone + Eq, Theme: Catalog + Catalog, Renderer: Renderer + Renderer,
{ /* private fields */ }
Available on crate feature ribbon only.
A labeled section within a Ribbon that clusters related widgets. It is resized by the Ribbon depending on what the content function given to the constructor chooses to provide.

Panics

Panics if the content function does not produce at least one element. Panics if the elements produced by the content function are not sorted in size.

Implementations

Source

impl<'a, Id, Message, Theme, Renderer> Group<'a, Id, Message, Theme, Renderer>
where Id: Clone + Eq, Message: 'a + Clone, Theme: 'a + Catalog + Catalog + Catalog, <Theme as Catalog>::Class<'a>: From<StyleFn<'a, Theme>>, Renderer: 'a + Renderer + Renderer + Renderer, <Renderer as Renderer>::Font: From<Font>, <Renderer as Renderer>::Paragraph: Clone,

pub fn new( id: Id, header: impl IntoFragment<'a>, content: impl Fn(Size) -> Option<Element<'a, Message, Theme, Renderer>> + 'a, ) -> Self
where <Theme as Catalog>::Class<'a>: From<StyleFn<'a, Theme>>,

Creates a new Group with the provided header and content function.

pub fn header_size(self, size: impl Into<Pixels>) -> Self

Sets the size of the Group header.

pub fn header_line_height(self, line_height: impl Into<LineHeight>) -> Self

Sets the line height of the Group header.

pub fn header_font(self, font: impl Into<Renderer::Font>) -> Self

Sets the font of the Group header.

pub fn header_wrapping(self, wrapping: Wrapping) -> Self

Sets the Wrapping of the Group header.

pub fn on_launcher_press(self, on_press: Message) -> Self

Sets the message that will be sent when the launcher button is pressed.

pub fn on_collapsed_press(self, on_press: Message) -> Self

Sets the message that will be sent when the Size::Collapsed button is pressed

pub fn on_collapsed_press_with( self, on_press: impl Fn() -> Message + 'a, ) -> Self

Sets the message that will be sent when the Size::Collapsed button is pressed

This is analogous to Group::on_collapsed_press, but using a closure to produce the message.

pub fn header_style(self, style: impl Fn(&Theme) -> Style + 'a) -> Self
where <Theme as Catalog>::Class<'a>: From<StyleFn<'a, Theme>>,

Sets the style of the Group header.

pub fn launcher_style( self, style: impl Fn(&Theme, Status) -> Style + 'a, ) -> Self
where <Theme as Catalog>::Class<'a>: From<StyleFn<'a, Theme>>,

Sets the style of the Group launcher button.

pub fn collapsed_style( self, style: impl Fn(&Theme, Status) -> Style + 'a, ) -> Self
where <Theme as Catalog>::Class<'a>: From<StyleFn<'a, Theme>>,

Sets the style of the Group Size::Collapsed button.