Ribbon

Struct Ribbon 

pub struct Ribbon<'a, Id, Message, Theme = Theme, Renderer = Renderer>
where Id: Clone + Eq, Theme: Catalog + Catalog + Catalog, Renderer: Renderer + Renderer,
{ /* private fields */ }
Available on crate feature ribbon only.
A horizontal collection of Groups which change their appearance and layout when the Ribbon is resized.

Implementations

Source

impl<'a, Id, Message, Theme, Renderer> Ribbon<'a, Id, Message, Theme, Renderer>
where Id: Clone + Eq, Message: 'a + Clone, Theme: 'a + Catalog + Catalog + Catalog + Catalog, <Theme as Catalog>::Class<'a>: From<StyleFn<'a, Theme>>, Renderer: 'a + Renderer + Renderer + Renderer, <Renderer as Renderer>::Font: From<Font>, <Renderer as Renderer>::Paragraph: Clone,

pub fn new( groups: impl IntoIterator<Item = Group<'a, Id, Message, Theme, Renderer>>, ) -> Self

Creates a new Ribbon which the provided Groups.

pub fn width(self, width: impl Into<Length>) -> Self

Sets the width of the Ribbon.

pub fn height(self, height: impl Into<Length>) -> Self

Sets the height of the Ribbon.

pub fn spacing(self, amount: impl Into<Pixels>) -> Self

Sets the spacing between Groups.

pub fn padding<P: Into<Padding>>(self, padding: P) -> Self

Sets the Padding of the Ribbon.

pub fn open_group(self, id: Id) -> Self

Opens the Group as a dropdown when collapsed.

Panics

Panics if no Group in the Ribbon has the provided id.

pub fn on_group_dropdown_dismiss(self, on_dismiss: Message) -> Self

Sets the message that will be sent when the Group collapsed dropdown is dismissed.

pub fn on_group_dropdown_dismiss_with( self, on_dismiss: impl Fn() -> Message + 'a, ) -> Self

Sets the message that will be sent when the Group collapsed dropdown is dismissed.

This is analogous to Ribbon::on_group_dropdown_dismiss, but using a closure to produce the message.

pub fn style(self, style: impl Fn(&Theme) -> Style + 'a) -> Self
where <Theme as Catalog>::Class<'a>: From<StyleFn<'a, Theme>>,

Sets the style of the Ribbon.